<?php

   /*
    *  squirrel_logger v1.4
    *  by Ron Chinn <ron@squeaksoft.com>
    *  (c) 2003 GNU GPL
    *
    *  See the README file in the source distribution for instructions.
    *
   */


   global $sl_logfile, $sl_delimiter, $sl_dateformat, $sl_namelookups;
   global $sl_use_file, $sl_use_syslog, $sl_syslog_priority;

   // --------------------------------------------------------------------
   // ** Modify the following settings for your particular installation **
   // --------------------------------------------------------------------

   // Do you want to use the syslog facility?
   //
   // valid settings are TRUE and FALSE

   $sl_use_syslog = FALSE;   // Default is FALSE


   // If using syslog, which priority should events be logged with?
   //
   // Valid options:  LOG_EMERG, LOG_ALERT, LOG_CRIT, LOG_ERR, LOG_WARNING,
   //                 LOG_NOTICE, LOG_INFO, LOG_DEBUG

   $sl_syslog_priority = LOG_INFO;  // Default is LOG_INFO


   // Do you want to use a text file for logging? 
   // (This is the original behavior of squirrel_logger)
   //
   // valid settings are TRUE and FALSE

   $sl_use_file = TRUE;  // default is TRUE

   // The location of your log file.  Make sure the user your webserver runs as
   // can write to this file.
   //
   // example:  $sl_logfile = "../data/access_log";
   //

   $sl_logfile = "../data/access_log";


   // Specify the delimiter used in between the fields of the log entry
   //
   // example:  $sl_delimiter = "\t";  (use tabs)
   //

   $sl_delimiter= ",";

   // Specify what date format you want
   //
   // See the PHP manual for the date function for help
   // at http://www.php.net/manual/en/function.date.php
   //
   // examples:  
   //
   //    "m/d/y G:i:s"     ==  03/10/2001 05:16:08
   //    "F j, Y, g:i a"   ==  March 10, 2001, 5:16 am
   //    "D M j Y G:i:s T" ==  Sat Mar 10 2001 15:16:08 CDT
   //

   $sl_dateformat = "m/d/Y G:i:s";


   // Turn hostname lookups on or off
   // Valid options are TRUE and FALSE
   //
   // example:   $sl_namelookups = TRUE;

   $sl_namelookups = FALSE;   // default is FALSE



// -----------------------------------------------------------------------
// You don't need to modify anything below this line
// -----------------------------------------------------------------------

function squirrelmail_plugin_init_squirrel_logger()
{ 
  global $squirrelmail_plugin_hooks;
  $squirrelmail_plugin_hooks["login_verified"]["squirrel_logger"] = "squirrel_logger_login";
  $squirrelmail_plugin_hooks["logout"]["squirrel_logger"] = "squirrel_logger_logout";
  $squirrelmail_plugin_hooks["invalid_login"]["squirrel_logger"] = "squirrel_logger_invalid";
}


// -------------------------------------------------
// Log a successful login
// -------------------------------------------------

function squirrel_logger_login()
{
  global $sl_logfile, $sl_delimiter, $sl_dateformat, $login_username;
  global $sl_namelookups;
  global $sl_use_syslog, $sl_syslog_priority, $sl_use_file;


  $date_str = date($sl_dateformat);
  $ip_str = getenv("REMOTE_ADDR");
    
  // Do name lookup if feature is enabled
  if ($sl_namelookups == TRUE)
    $ip_str = gethostbyaddr($ip_str);

  // Do flat file log, if enabled
  if ($sl_use_file == TRUE)
  {
    $d = $sl_delimiter;
    $log_str = "LOGIN" . $d . $login_username . $d . $ip_str . $d . $date_str;

    $fp=fopen($sl_logfile,"a");
    fputs($fp,$log_str . "\n");
    fclose($fp);
  }

  // Do syslog, if enabled
  if ($sl_use_syslog == TRUE)
  {
    $log_str = "Successful webmail login from " . $ip_str . " by " . $login_username . ".";
    syslog($sl_syslog_priority, $log_str);
  }

}





// -------------------------------------------------
// Log a successful logout
// -------------------------------------------------

function squirrel_logger_logout()
{
  global $sl_logfile, $sl_delimiter, $sl_dateformat, $username;
  global $sl_namelookups;
  global $sl_use_syslog, $sl_syslog_priority, $sl_use_file;

  $date_str = date($sl_dateformat);
  $ip_str = getenv("REMOTE_ADDR");
    
  // Do name lookup if feature is enabled
  if ($sl_namelookups == TRUE)
    $ip_str = gethostbyaddr($ip_str);

  // Do flat file log, if enabled
  if ($sl_use_file == TRUE)
  {
    $d = $sl_delimiter;

    // Check for a timed-out session
    if (strstr(getenv("REQUEST_URI"),"timeout") == TRUE)
      $event_str = "TIMEOUT";
    else
      $event_str = "LOGOUT";  

    $log_str = $event_str . $d . $username . $d . $ip_str . $d . $date_str;

    $fp=fopen($sl_logfile,"a");
    fputs($fp,$log_str . "\n");
    fclose($fp);
  }

  // Do syslog, if enabled
  if ($sl_use_syslog == TRUE)
  {
    // Is this a timed-out session?
    if (strstr(getenv("REQUEST_URI"),"timeout") == TRUE)
      $log_str = "Webmail session timed out for " . $username . " from " . $ip_str . ".";
    else // regular logout
      $log_str = "Webmail user " . $username . " from " . $ip_str . " logged out.";

    syslog($sl_syslog_priority, $log_str);
  }
}




// -------------------------------------------------
// Log an invalid login attempt
//
// This only works if the admin adds a hook in
//  functions/imap_general.php
// see the README for instructions
// -------------------------------------------------

function squirrel_logger_invalid()
{
  global $sl_logfile, $sl_delimiter, $sl_dateformat, $login_username;
  global $sl_namelookups;
  global $sl_use_syslog, $sl_syslog_priority, $sl_use_file;
    
  $date_str = date($sl_dateformat);
  $ip_str = getenv("REMOTE_ADDR");

  // Do name lookup if feature is enabled
  if ($sl_namelookups == TRUE)
    $ip_str = gethostbyaddr($ip_str);

  // Do flat file log, if enabled
  if ($sl_use_file == TRUE)
  {
    $d = $sl_delimiter;
    $log_str = "INVALID" . $d . $login_username . $d . $ip_str . $d . $date_str;

    $fp=fopen($sl_logfile,"a");
    fputs($fp,$log_str . "\n");
    fclose($fp);
  }

  // Do syslog, if enabled
  if ($sl_use_syslog == TRUE)
  {
    $log_str = "Failed webmail login from " . $ip_str . " by " . $login_username . ".";
    syslog($sl_syslog_priority, $log_str);
  }

}


?>
